Coverage for hookee/exception.py: 100.00%

1 __author__ = "Alex Laird"

2 __copyright__ = "Copyright 2023, Alex Laird"

3 __version__ = "1.2.0"

4

5

6 class HookeeError(Exception):

7 """

8 Raised when a general ``hookee`` error has occurred.

9 """

10 pass

11

12

13 class HookeeConfigError(HookeeError):

14 """

15 Raised when there is an error initializing ``hookee` configuration.

16 """

17 pass

18

19

20 class HookeePluginValidationError(HookeeError):

21 """

22 Raised when a module fails to validate as a valid ``hookee`` plugin.

23 """

24 pass